@@ -5,7 +5,55 @@ import os
 from .Colours import Style
 
 
+def LINKCODE(link: str, text: str = None):
+    if text is None:
+        text = link
+    return f"\u001b]8;;{link}\u001b\\{text}\u001b]8;;\u001b\\"
+
+
+def TIME():
+    def convertToFull(value):
+        vs = str(value)
+        if value < 10:
+            vs = f"0{value}"
+
+        return vs
+
+    ctime = datetime.datetime.now()
+    h = ctime.hour
+    m = ctime.minute
+    s = ctime.second
+
+    hs = convertToFull(h)
+    ms = convertToFull(m)
+    ss = convertToFull(s)
+
+    return hs, ms, ss
+
+
 def main(
+    name: str,
+    twitter: str = None,
+    youtube: str = None,
+    github: str = None,
+    *,
+    colour: str = None
+):
+    """
+    Prints off a watermark / header style thing on call.
+
+    Args:
+        name (str): The username
+        twitter (str, optional): Twitter link
+        youtube (str, optional): Youtube link
+        github (str, optional): Github link
+        colour (str, optional): Colour of the watermark
+    """
+    watermark(name, twitter, youtube, github, colour=colour)
+    print("Please use `watermark` instead of `main` in function. This will be removed in v1.5.0")
+
+
+def watermark(
     name: str,
     twitter: str = None,
     youtube: str = None,
@@ -23,46 +71,38 @@ def main(
         github (str, optional): Github link
         colour (str, optional): Colour of the watermark
     """
-    fileName: str = ""
+    fileName: str = "__main__"
 
     for frame in inspect.stack()[1:]:
         if frame.filename[0] != "<":
             fileName = os.path.basename(frame.filename)[:-3]
             break
 
-    twitURL = "https://twitter.com/DragMine149"
-    youURL = "https://youtube.com/channel/UCOnORrEI4GhYtivLQJpOoJQ"
-    gitURL = "https://github.com/dragmine149"
-
-    # Prints off my watermark
     line = "-" * os.get_terminal_size().columns
 
-    # Gets data
     data = ""
     if twitter is not None:
-        data += f"\u001b]8;;{twitter}\u001b\\Twitter\u001b]8;;\u001b\\, "
+        data += LINKCODE(twitter, "Twitter")
     if youtube is not None:
-        data += f"\u001b]8;;{youtube}\u001b\\Youtube\u001b]8;;\u001b\\, "
+        data += LINKCODE(youtube, "Youtube")
     if github is not None:
-        data += f"\u001b]8;;{github}\u001b\\Github\u001b]8;;\u001b\\"
+        data += LINKCODE(github, "Github")
 
-    # If data is null
     if data == "":
         data = "Nothing linked"
 
     mydata = ""
-    mydata += f"\u001b]8;;{twitURL}\u001b\\Twitter\u001b]8;;\u001b\\, "
-    mydata += f"\u001b]8;;{youURL}\u001b\\Youtube\u001b]8;;\u001b\\, "
-    mydata += f"\u001b]8;;{gitURL}\u001b\\Github\u001b]8;;\u001b\\"
+    mydata += LINKCODE("https://twitter.com/DragMine149", "Twitter") + ","
+    mydata += LINKCODE("https://youtube.com/@dragmine", "Youtube") + ","
+    mydata += LINKCODE("https://github.com/dragmine149", "Github")
 
-    # Gets time
-    ctime = datetime.datetime.now()
+    h, m, s = TIME()
 
     print("\x1b[2J\x1b[H", end="")
     print(
         f"""{colour}{line}{Style.RESET_ALL}
 {fileName} made by {name} ({data}).
 Contains Functions.py made by dragmine149 ({mydata}).
-Activation Time: {ctime.hour}:{ctime.minute}:{ctime.second}
+Activation Time: {h}:{m}:{s}
 {colour}{line}{Style.RESET_ALL}"""
     )
